@@ -205,8 +205,7 @@ void Workspace::setupCompositing()
         scene->windowAdded( c );
     foreach( Unmanaged* c, unmanaged )
         scene->windowAdded( c );
-    delete popup; // force re-creation of the Alt+F3 popup (opacity option)
-    popup = NULL;
+    discardPopup(); // force re-creation of the Alt+F3 popup (opacity option)
 #else
     kDebug( 1212 ) << "Compositing was not available at compile time";
 #endif
@@ -251,8 +250,10 @@ void Workspace::finishCompositing()
             i.setOpacity( static_cast< unsigned long >((*it)->opacity() * 0xffffffff ));
             }
         }
-    delete popup; // force re-creation of the Alt+F3 popup (opacity option)
-    popup = NULL;
+    discardPopup(); // force re-creation of the Alt+F3 popup (opacity option)
+    // discard all Deleted windows (#152914)
+    while( !deleted.isEmpty())
+        deleted.first()->discard( Allowed );
 #endif
     }
 
@@ -313,6 +314,11 @@ void Workspace::performCompositing()
         || !overlay_visible ) // nothing is visible anyway
         {
         scene->idle();
+        // With vsync, next repaint is scheduled dynamically at the end of this function,
+        // and it can have a very short timeout. If we now idle here, make sure the idling
+        // does not actually caused heavy load by firing the timer often too quickly.
+        if( compositeTimer.interval() != compositeRate )
+            compositeTimer.start( compositeRate );
         return;
         }
     // create a list of all windows in the stacking order
