@@ -228,7 +228,7 @@ void Workspace::init()
 //     topDock = 0L;
 //     maximizedWindowCounter = 0;
 
-    supportWindow = new QWidget;
+    supportWindow = new QWidget( NULL, Qt::X11BypassWindowManagerHint );
     XLowerWindow( display(), supportWindow->winId()); // see usage in layers.cpp
 
     XSetWindowAttributes attr;
@@ -459,7 +459,7 @@ Workspace::~Workspace()
         (*it)->release();
     delete tab_box;
     delete popupinfo;
-    delete popup;
+    discardPopup();
     XDeleteProperty(display(), rootWindow(), atoms->kwin_running);
 
     writeWindowRules();
@@ -579,7 +579,10 @@ void Workspace::removeClient( Client* c, allowed_t )
     if( client_keys_client == c )
         setupWindowShortcutDone( false );
     if( !c->shortcut().isEmpty())
+        {
         c->setShortcut( QString() ); // remove from client_keys
+        clientShortcutUpdated( c ); // needed, since this is otherwise delayed by setShortcut() and wouldn't run
+        }
 
     if( c->isDialog())
         Notify::raise( Notify::TransDelete );
@@ -1145,7 +1148,10 @@ QStringList Workspace::configModules(bool controlCenter)
 
 void Workspace::configureWM()
     {
-	KToolInvocation::kdeinitExec( "kcmshell4", configModules(false) );
+        QStringList args;
+        args << "--icon" << "preferences-system-windows"
+             << configModules(false) ;
+        KToolInvocation::kdeinitExec( "kcmshell4", args );
     }
 
 /*!
@@ -1178,7 +1184,7 @@ bool Workspace::isNotManaged( const QString& title )
  */
 void Workspace::refresh()
     {
-    QWidget w;
+    QWidget w( NULL, Qt::X11BypassWindowManagerHint );
     w.setGeometry( QApplication::desktop()->geometry() );
     w.show();
     w.hide();
@@ -2375,7 +2381,7 @@ void Workspace::setupTopMenuHandling()
     connect( topmenu_selection, SIGNAL( lostOwnership()), this, SLOT( lostTopMenuSelection()));
     disconnect( topmenu_watcher, SIGNAL( lostOwner()), this, SLOT( lostTopMenuOwner()));
     managing_topmenus = true;
-    topmenu_space = new QWidget;
+    topmenu_space = new QWidget( NULL, Qt::X11BypassWindowManagerHint );
     Window stack[ 2 ];
     stack[ 0 ] = supportWindow->winId();
     stack[ 1 ] = topmenu_space->winId();
